Learn R Programming

PACLasso (version 1.0.0)

lin.int.ineq: Initialize Linear Programming Fit with Inequality Constraints

Description

This function is called internally by lars.ineq to get the linear programming initial fit if the user requests implementation of the algorithm starting at the largest lambda value and proceeding backwards.

Usage

lin.int.ineq(C.full, b)

Arguments

C.full

complete constraint matrix C (with inequality constraints of the form C.full*beta >= b))

b

constraint vector b

Value

beta the initial beta vector of coefficients to use for the PaC algorithm

Examples

Run this code
# NOT RUN {
random_data = generate.data(n = 500, p = 20, m = 10)
lin_start = lin.int.ineq(random_data$C.full, random_data$b)
lin_start

# }

Run the code above in your browser using DataLab