lin.int.ineq: Initialize Linear Programming Fit with Inequality Constraints
Description
This function is called internally by lars.ineq
to get the linear programming initial fit if the user requests
implementation of the algorithm starting at the largest lambda
value and proceeding backwards.
Usage
lin.int.ineq(C.full, b)
Arguments
C.full
complete constraint matrix C (with inequality constraints of the form C.full*beta >= b))
b
constraint vector b
Value
beta the initial beta vector of coefficients to use for the PaC algorithm